package info.cobaltduck.listeners;

import info.cobaltduck.PetAger;
import info.cobaltduck.gui.InputPanel;
import info.cobaltduck.gui.OutputPanel;
import info.cobaltduck.model.*;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

public class CalculateListener implements ActionListener {

	@Override
	public void actionPerformed(ActionEvent e) {
		
		InputPanel input = PetAger.getInput();
		OutputPanel output = PetAger.getOutput();
		
		try {
			// first obtain and validate the input
			String name = input.nameField.getText();
			if (name == null || name.equals("")) {
				throw new Exception ("No name has been entered.");
			}
			String ageString = input.ageField.getText();
			int age = Integer.parseInt(ageString);
			
			// then instantiate the Pet object
			Pet usersPet;
			if (input.cat.isSelected() || input.small.isSelected()) {
				usersPet = new SmallDogOrCat();
			}
			else if (input.medium.isSelected()) {
				usersPet = new MediumDog();
			}
			else if(input.large.isSelected()) {
				usersPet = new LargeDog();
			}
			else throw new Exception("You must select a size.");
			
			usersPet.setName(name);
			usersPet.setCalendarAge(age);
			
			// finally call OutputPanel's message methods
			String classic = "Under the classic system, " + usersPet.getName() + 
				" is equivalent to " + usersPet.getClassicAge() + " years old.";
			String modern = "Under the modern system, " + usersPet.getName() +
				" is equivalent to " + usersPet.getEquivalentAge() + " years old.";
						
			output.setMessage1(classic);
			output.setMessage2(modern);
		}
		
		catch (NumberFormatException error) {
			// send an error message to OutputPanel
			output.setMessage1("Age must be a whole number.");
			output.setMessage2("Please return to form and try again.");
		}
		catch (Exception exception) {
			output.setMessage1(exception.getMessage());
			output.setMessage2("Please return to form and try again.");
		}
		
		finally {
			output.changeMessages();
		}
		

	}

}
